@@ -347,9 +347,9 @@ describe 'horizon' do
         params.merge!({
           :listen_ssl        => true,
           :servername        => 'some.host.tld',
-          :horizon_cert      => '/etc/pki/tls/certs/httpd.crt',
-          :horizon_key       => '/etc/pki/tls/private/httpd.key',
-          :horizon_ca        => '/etc/pki/tls/certs/ca.crt',
+          :ssl_cert          => '/etc/pki/tls/certs/httpd.crt',
+          :ssl_key           => '/etc/pki/tls/private/httpd.key',
+          :ssl_ca            => '/etc/pki/tls/certs/ca.crt',
           :ssl_verify_client => 'optional',
         })
       end
@@ -358,9 +358,9 @@ describe 'horizon' do
         is_expected.to contain_class('horizon::wsgi::apache').with({
           :bind_address      => nil,
           :listen_ssl        => true,
-          :horizon_cert      => '/etc/pki/tls/certs/httpd.crt',
-          :horizon_key       => '/etc/pki/tls/private/httpd.key',
-          :horizon_ca        => '/etc/pki/tls/certs/ca.crt',
+          :ssl_cert          => '/etc/pki/tls/certs/httpd.crt',
+          :ssl_key           => '/etc/pki/tls/private/httpd.key',
+          :ssl_ca            => '/etc/pki/tls/certs/ca.crt',
           :ssl_verify_client => 'optional',
         })
       end
